@@ -970,7 +970,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub new {
     my ($class) = @_;
@@ -997,10 +997,7 @@ Lang::HL::Syntax - Perl extension for blah blah blah
 
 =head1 SYNOPSIS
 
-  use Lang::HL::Syntax;
-
-  my $syntaxObject = Lang::HL::Syntax->new();
-  $code = $syntaxObject($code);
+	$> hle <directory>
 
 =head1 DESCRIPTION
 
